*******************************************************************************
*INSTRUCTIONS                                                                 *
*                                                                             *
* 1. Put the cumulative file in the c:\temp folder and call it "cumfile.dta"  *
* 2. Put the 1972 NES file in the c:\temp folder and call it "nes1972.dta"    *
*******************************************************************************


clear
cd c:\temp
set mem 500m
use cumfile.dta

************************
*HOUSEKEEPING VARIABLES*
************************
gen year=VCF0004 
gen id=VCF0006 

**************
*YEAR DUMMIES*
**************

gen year_1=0
replace year_1=1 if year==1972
gen year_2=0
replace year_2=1 if year==1976
gen year_3=0
replace year_3=1 if year==1980
gen year_4=0
replace year_4=1 if year==1984
gen year_5=0
replace year_5=1 if year==1988
gen year_6=0
replace year_6=1 if year==1996


*************
*VOTE CHOICE*
*************
*1=Democrat; 0=Republican*

gen vote=VCF0704 
recode vote 2=0 3=. 0=.


*******************
*CONTROL VARIABLES*
*******************

*party identification - point scale; recoded -1 (strong republican) to 1 (strong democrat)*
gen pid7=VCF0301 
recode pid7 0=. 9=.
replace pid7=((((1-(pid7-1)/6)*6)-3)/3)
*gender*
gen female=0
replace female=1 if VCF0104  ==2
*race*
gen black=0
replace black=1 if VCF0105 ==2
*income*
gen income = VCF0114 
recode income 0=.
replace income=(income-1)/4

*****************
*ISSUE POSITIONS*
*****************
*lbc=liberal/liberal consrvative*
*job=guaranteed jobs*
*mad= minority aid*
*S_=self;R_=Republican candidate; D_=Democratic candidate*

gen S_lbc=VCF0803
gen S_job=VCF0809 
gen S_mad=VCF0830 

gen D_lbc=VCF9088
gen D_job=VCF9087 
gen D_mad=VCF9084

gen R_lbc=VCF9096
gen R_job=VCF9095 
gen R_mad=VCF9092 

foreach x of varlist S_lbc S_job S_mad D_lbc D_job D_mad R_lbc R_job R_mad {
recode `x' 0=. 8=. 9=.
}



**********************************
*UNCERTAINITY DEPENDENT VARIABLES*
**********************************

*note: these are dummy variables that are scored "0" if the respondent did not answer a question and "1" if they did.*
*these variables will be flipped below to make them measures of uncertainity*

gen u_d_lbc=VCF9088
gen u_d_job=VCF9087 
gen u_d_mad=VCF9084

gen u_r_lbc=VCF9096
gen u_r_job=VCF9095 
gen u_r_mad=VCF9092 


foreach x of varlist  u_d_lbc u_d_job u_d_mad u_r_lbc u_r_job u_r_mad {
recode `x' 2=1 3=1 4=1 5=1 6=1 7=1 8=0 9=.
}

save, replace

********************************
*IMPORTING 1972 JOBS PLACEMENTS*
********************************
use nes1972.dta, clear
gen id= v720002
gen year=1972

egen S_job72=rmean(v720172  v720613)
egen R_job72=rmean(v720173  v720614)
egen D_job72=rmean(v720174  v720615)

keep year id S_job72 R_job72 D_job72
sort year id
save 72job, replace
use cumfile, clear
sort year id
merge year id using 72job

egen j1=rmean(S_job S_job72) if year==1972
egen j2=rmean(R_job R_job72) if year==1972
egen j3=rmean(D_job D_job72) if year==1972

replace S_job=j1 if year==1972
replace R_job=j2 if year==1972
replace D_job=j3 if year==1972

drop j1 j2 j3 _merge

replace u_d_job=1 if D_job>0 & D_job<8 & year==1972
replace u_r_job=1 if R_job>0 & R_job<8 & year==1972


***************************************
*CREATING UNCERTINAITY DUMMY VARIABLES*
***************************************
*flip direction of the item placement dummies to make them uncertianity DVs*

foreach x of varlist  u_d_lbc u_d_job u_d_mad u_r_lbc u_r_job u_r_mad {
recode `x' 0=1 1=0
}
*************************************
*VARIABLES FOR UNCERTAINITY MEASURES*
*************************************

*information level*
gen i1=VCF0050a
gen i2=VCF0050b 
recode i1 0=. 9=.
recode i2 0=. 9=.
egen info=rmean(i1 i2)
replace info=1-((info-1)/4)


*media attention: different for 1988 when there are only 3 items*
gen media=(VCF0728-1)/4
recode media -.25=.
gen m1=(VCF0725-1)
gen m2=(VCF0726-1)
gen m3=(VCF0727-1)
recode m1 -1=.
recode m2 -1=.
recode m3 -1=.

egen media88=rmean(m1 m2 m3) if year==1988
replace media=media88 if year==1988

*campaign work - 1-6 scale recoded 0-1*
gen campwork=VCF0723 
recode campwork 0=.
replace campwork=(campwork-1)/5

*campaign interest*
gen campint=VCF0310  
recode campint 0=. 9=.
replace campint= (campint-1)/2


*follow politics*
gen followpol=VCF0313  
recode followpol 0=. 9=.
replace followpol = (followpol-1)/3

*education: dummy variables*
tab VCF0110 if VCF0110 >0, g(ed)
rename ed1 edu_gs
rename ed2 edu_hs
rename ed3 edu_scol
rename ed4 edu_col

*age*
gen age=VCF0101/100
recode age 0=.

*partisanship dummies*
tab VCF0301 if VCF0301>0 ,g(partyid)
rename partyid1 Srep
rename partyid2 Wrep
rename partyid3 Irep
rename partyid4 Indep
rename partyid5 Idem
rename partyid6 Wdem
rename partyid7 Sdem
rename partyid8 nopid

***********
*VARIANCES*
***********
*predicted probability of not answering*
*generated year-by-year, then combined*


*1972*
*note: 1972 runs don't include media because it was split sampled*
probit u_r_lbc  info campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1972
predict r_v1_lbc72 if year==1972

probit u_r_job  info campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1972
predict r_v1_job72 if year==1972

probit u_r_mad  info campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1972
predict r_v1_mad72 if year==1972

probit u_d_lbc  info campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1972
predict d_v1_lbc72 if year==1972

probit u_d_job  info campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1972
predict d_v1_job72 if year==1972

probit u_d_mad  info campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1972
predict d_v1_mad72 if year==1972

*1976*
probit u_r_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1976
predict r_v1_lbc76 if year==1976

probit u_r_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1976
predict r_v1_job76 if year==1976

probit u_r_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1976
predict r_v1_mad76 if year==1976

probit u_d_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1976
predict d_v1_lbc76 if year==1976

probit u_d_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1976
predict d_v1_job76 if year==1976

probit u_d_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1976
predict d_v1_mad76 if year==1976


*1980*
probit u_r_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1980
predict r_v1_lbc80 if year==1980

probit u_r_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1980
predict r_v1_job80 if year==1980

probit u_r_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1980
predict r_v1_mad80 if year==1980

probit u_d_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1980
predict d_v1_lbc80 if year==1980

probit u_d_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1980
predict d_v1_job80 if year==1980

probit u_d_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1980
predict d_v1_mad80 if year==1980


*1984*
probit u_r_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1984
predict r_v1_lbc84 if year==1984

probit u_r_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1984
predict r_v1_job84 if year==1984

probit u_r_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1984
predict r_v1_mad84 if year==1984

probit u_d_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1984
predict d_v1_lbc84 if year==1984

probit u_d_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1984
predict d_v1_job84 if year==1984

probit u_d_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1984
predict d_v1_mad84 if year==1984


*1988*
probit u_r_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1988
predict r_v1_lbc88 if year==1988

probit u_r_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1988
predict r_v1_job88 if year==1988

probit u_r_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1988
predict r_v1_mad88 if year==1988

probit u_d_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1988
predict d_v1_lbc88 if year==1988

probit u_d_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1988
predict d_v1_job88 if year==1988

probit u_d_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1988
predict d_v1_mad88 if year==1988


*1996*
probit u_r_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1996
predict r_v1_lbc96 if year==1996

probit u_r_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1996
predict r_v1_job96 if year==1996

probit u_r_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1996
predict r_v1_mad96 if year==1996

probit u_d_lbc  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1996
predict d_v1_lbc96 if year==1996

probit u_d_job  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1996
predict d_v1_job96 if year==1996

probit u_d_mad  info media campwork  campint followpol  female black edu_gs edu_scol edu_col age Sdem Wdem Idem Irep Wrep Srep nopid if year==1996
predict d_v1_mad96 if year==1996

*combine the measures*
egen r_v1_lbc=rmean(r_v1_lbc72 r_v1_lbc76 r_v1_lbc80 r_v1_lbc84 r_v1_lbc88 r_v1_lbc96)

egen r_v1_job=rmean(r_v1_job72 r_v1_job76 r_v1_job80 r_v1_job84 r_v1_job88 r_v1_job96)

egen r_v1_mad=rmean(r_v1_mad72 r_v1_mad76 r_v1_mad80 r_v1_mad84 r_v1_mad88 r_v1_mad96)

egen d_v1_lbc=rmean(d_v1_lbc72 d_v1_lbc76 d_v1_lbc80 d_v1_lbc84 d_v1_lbc88 d_v1_lbc96)

egen d_v1_job=rmean(d_v1_job72 d_v1_job76 d_v1_job80 d_v1_job84 d_v1_job88 d_v1_job96)

egen d_v1_mad=rmean(d_v1_mad72 d_v1_mad76 d_v1_mad80 d_v1_mad84 d_v1_mad88 d_v1_mad96)


save, replace

******************
*CREATE DATA FILE*
******************

local issues   "lbc job mad "
local cont     "female black pid7 income year_2 year_3 year_4 year_5 year_6"

local noIssue : word count `issues'

local i = 1
while `i' <= `noIssue' {  
   local is: word `i' of `issues'
   local r "`r' S_`is'"
   local cA "`cA' D_`is'"
   local cB "`cB' R_`is'"
   local is = substr("`is'",1,3)
   local vA "`vA' d_v1_`is'"
   local vB "`vB' r_v1_`is'"
   local i = `i' + 1
}

replace vote = 2*vote - 1
egen miss = rmiss(vote `r' `cA' `cB' `vA' `vB' `cont')
keep if miss==0
keep vote `r' `cA' `cB' `vA' `vB' `cont'
order vote `r' `cA' `cB' `vA' `vB' `cont'
save cumdata, replace


***************
*1972 GAMBLING*
***************
use nes1972.dta, clear
gen id= v720002

*specific gambling activities*

gen g1=v721036
recode g1 1=1 5=0
gen g2=v721037
recode g2 1=1 5=0
gen g3=v721040
recode g3 1=1 5=0
gen g4=v721044
recode g4 1=1 5=0
gen g5=v721045
recode g5 1=1 5=0
gen g6=v721046
recode g6 1=1 5=0

egen gambtot=rmean(g1-g6)
*how much spend on gambling*
gen spend=v721060
replace spend=0 if gambtot==0
gen lnspend=(ln(spend+1))/10

*if you're a big winner,  you keep playing*
gen playwin=v721061
recode playwin 1=1 5=0

*generation of risk scores*
egen gambling=rmean(g1 g2 g3 g4 g5 g6 lnspend playwin)
gen gambdum=.
replace gambdum=0 if gambling>-1 & gambling<=.13
replace gambdum=1 if gambling>.13 & gambling<=2

keep id gambdum
gen year=1972
sort year id
save 1972gamb.dta, replace

use cumfile, clear
keep if year==1972
sort year id
merge year id using 1972gamb
save 1972gamb.dta, replace

************************************
*CREATE DATA FILE FOR 1972 ANALYSIS*
************************************

local issues   "lbc job mad "
local cont     "female black pid7 income "

local noIssue : word count `issues'

local i = 1
while `i' <= `noIssue' {  
   local is: word `i' of `issues'
   local r "`r' S_`is'"
   local cA "`cA' D_`is'"
   local cB "`cB' R_`is'"
   local is = substr("`is'",1,3)
   local vA "`vA' d_v1_`is'"
   local vB "`vB' r_v1_`is'"
   local i = `i' + 1
}

replace vote = 2*vote - 1
egen miss = rmiss(vote `r' `cA' `cB' `vA' `vB' `cont' gambdum )
keep if miss==0
keep vote `r' `cA' `cB' `vA' `vB' `cont' gambdum 
order vote `r' `cA' `cB' `vA' `vB' `cont' gambdum 
save 72runs, replace
