
rm(list=ls())
library("spatrisk")
library("foreign")

set.seed(123)

setwd("d:\temp")
dta <- read.dta("cumdata.dta")
vote <- dta[,1]
dta <- dta[,-1]

egamma <- 3.449  # This is the gamma param from the estimation
mcsize <- 1500

cat("Getting scaled uncertainties (sd of beliefs about locations) and distances to expected locations...\n") 
scaled.uncertainty <- egamma*dta[,10:15]
avg.sd <- apply(scaled.uncertainty,2,mean)
distance.D <- abs(dta[,1:3]-dta[4:6])
distance.R <- abs(dta[,1:3]-dta[7:9])
avg.distance.D <- apply(distance.D,2,mean)
avg.distance.R <- apply(distance.R,2,mean)

cat("Getting percent of cases in which uncertainty is sufficient to lower utility...\n")
pct.discounting.D <- apply( distance.D < 1.96*scaled.uncertainty[,1:3], 2, mean)
pct.discounting.R <- apply( distance.R < 1.96*scaled.uncertainty[,4:6], 2, mean)

point <- rnorm(mcsize)

uloss.D <- matrix(0,nrow(dta),3)
uloss.R <- matrix(0,nrow(dta),3)


#
# What fraction of the EU is due to uncertainty?
#
utilityLoss <- function(p,i,j) { 
    if (p=="D") {   
        loc <- dta[j,i+3] + scaled.uncertainty[j,i]*point 
        eu <-  mean(abs(loc-dta[j,i])) 
        r <- (eu-distance.D[j,i])
    }
    else if (p=="R") {
        loc <- dta[j,i+6] + scaled.uncertainty[j,i+3]*point 
        eu <-  mean(abs(loc-dta[j,i])) 
        r <- (eu-distance.R[j,i])  
    }
    r
}

quloss.R <- matrix(0,3,4)
quloss.D <- matrix(0,3,4)

cat("Getting utility loss...\n\n")
for( i in 1:3 ) {
    cat("Issue",i,"\n")
    flush.console()
    
    cat("\tWorking D\n")
    flush.console()
    uloss.D[,i] <- sapply(1:nrow(dta),function(j) utilityLoss("D",i,j))
    
    cat("\tWorking R\n")
    flush.console()
    loc <- dta[,i+7] + (scaled.uncertainty[,i+3] %*% t(as.matrix(point)))
    uloss.R[,i] <- sapply(1:nrow(dta),function(j) utilityLoss("R",i,j))

    quloss.R[i,] <- quantile(uloss.R,c(0.70,0.80,0.90,0.95))
    quloss.D[i,] <- quantile(uloss.D,c(0.70,0.80,0.90,0.95))
}
    
    
cat("Results for table 2\n")    
resD <- round(cbind(avg.sd[1:3],avg.distance.D,pct.discounting.D,quloss.D[,c(2,3,4)]),3)
colnames(resD) <- c("St.Dev","Distance","Pct.Affected","80th","90th","95th")
rownames(resD) <- c("Liberal/Conservative","Jobs","Minority Aid")
cat("\nDemocratic candidate:\n")
print(resD)

resR <- round(cbind(avg.sd[4:6],avg.distance.R,pct.discounting.R,quloss.R[,c(2,3,4)]),3)
colnames(resR) <- c("St.Dev","Distance","Pct.Affected","80th","90th","95th")
rownames(resR) <- c("Liberal/Conservative","Jobs","Minority Aid")
cat("\nRepublican candidate:\n")
print(resR)
